@@ -1,5 +1,5 @@
 // Copyright (C) 2021 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <qmockimagecapture.h>
 #include <qmockcamera.h>
@@ -40,7 +40,7 @@ void QMockImageCapture::captured()
     emit imageCaptured(m_captureRequest, QImage());
 
     QMediaMetaData metaData;
-    metaData.insert(QMediaMetaData::Author, QString::fromUtf8("Author"));
+    metaData.insert(QMediaMetaData::Author, QStringLiteral("Author"));
     metaData.insert(QMediaMetaData::Date, QDateTime(QDate(2021, 1, 1), QTime()));
 
     emit imageMetadataAvailable(m_captureRequest, metaData);
